@@ -1,5 +1,5 @@
 
-## Copyright (C) 2007, 2008, 2009, 2010, 2011 Red Hat, Inc.
+## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 ##  Jiri Popelka <jpopelka@redhat.com>
@@ -958,6 +958,8 @@ class JobViewer (GtkGUI):
                     except gnomekeyring.DeniedError:
                         debugprint ("gnomekeyring: denied for %s" %
                                     keyring_attrs)
+                    except Exception, e:
+                        debugprint ("gnomekeyring: caught exception %s" % e)
 
                 if try_keyring and c == None:
                     try:
@@ -1683,6 +1685,20 @@ class JobViewer (GtkGUI):
             # This seems to be some sort of 'magic' state reason that
             # is for internal use only.
             "com.apple.print.recoverable",
+
+            # Human-readable text for this reason has misleading wording,
+            # suppress it.
+            "connecting-to-device",
+
+            # "cups-remote-..." reasons have no human-readable text yet and
+            # so get considered as errors, suppress them, too.
+            "cups-remote-pending",
+            "cups-remote-pending-held",
+            "cups-remote-processing",
+            "cups-remote-stopped",
+            "cups-remote-canceled",
+            "cups-remote-aborted",
+            "cups-remote-completed"
             ]
 
         if reason.get_reason () in blacklist:
